powerdart_v2 library

Classes

MaxIndexedResult
This class hold the result of the maxIndexed
PsdResult
This class hold the result of the PSD computation

Functions

cumtrapz(List<double> y, List<double> x) List<double>
Returns the cumulative approximate integral of y via the trapezoidal method with respect to the coordinates or scalar spacing specified by x. y: List of double to integrate x: List of double representing the coordinates
find(List<double> data, bool test(double element)) Iterable<int>
Returns a list of index that pass the test. data: List of double test: method to test against the data
linspace(double start, double stop, {int num = 100, bool endpoint = true}) List<double>
Return evenly spaced numbers over a specified interval.
maxIndexed(List<double> signal) MaxIndexedResult
Return the max value and his index of the signal signal: List of double to find the max
psd(List<double> data, double fs) PsdResult
Compute the Power Spectral Density
trapz(List<double> y, List<double> x) double
Returns the approximate integral of y via the trapezoidal method with respect to the coordinates or scalar spacing specified by x. y: List of double to integrate x: List of double representing the coordinates