MaxIndexedResult class

This class hold the result of the maxIndexed

This class is used to simply and safely store the results of maxIndexed. value: the max value index: index of the max value

Constructors

MaxIndexedResult(double value, int index)

Properties

hashCode int
The hash code for this object.
no setteroverride
index int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override