PsdResult class

This class hold the result of the PSD computation

This class is used to simply and safely store the results of the PSD analysis. pxx: the psd values f: the normalized frequency vector

Constructors

PsdResult(List<double> pxx, List<double> f)
const

Properties

f List<double>
final
hashCode int
The hash code for this object.
no setteroverride
pxx List<double>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override