PsdResult class
This class hold the result of the PSD computation
This class is used to simply and safely store the results of the PSD analysis. pxx: the psd values f: the normalized frequency vector
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override